@@ -155,7 +155,9 @@ class HardwareViewSet(viewsets.ModelViewSet):
 
     def getChannels(self, hardware_id):
         channels = Hardware.objects.get(pk=str(hardware_id)).channel_set.all()
-        serialized_channels = ChannelSerializer(channels,many=True)
+        serialized_channels = []
+        for channel in channels:
+            serialized_channels.append(ChannelSerializer(channel).data)
         # if request.accepted_renderer.format == 'html':
         print('get channels '+ str(hardware_id))
         print(str(serialized_channels))
